@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,13 +24,14 @@ FilterActionMissingAccountDialog::FilterActionMissingAccountDialog(const QString
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select Account"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QLabel *label = new QLabel(this);
+    auto label = new QLabel(this);
     label->setObjectName(QStringLiteral("label"));
-    label->setText(i18n("Filter account is missing. "
-                        "Please select account to use with filter \"%1\"",
-                        filtername));
+    label->setText(
+        i18n("Filter account is missing. "
+             "Please select account to use with filter \"%1\"",
+             filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
     mAccountList = new MailCommon::KMFilterAccountList(this);
@@ -38,7 +39,7 @@ FilterActionMissingAccountDialog::FilterActionMissingAccountDialog(const QString
     mAccountList->applyOnAccount(lstAccount);
     mainLayout->addWidget(mAccountList);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
