@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "filteractionmissingtransportdialog.h"
 
-#include <KSharedConfig>
 #include <KLocalizedString>
+#include <KSharedConfig>
 
 #include <QDialogButtonBox>
 #include <QLabel>
-#include <QVBoxLayout>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 #include <MailTransport/TransportComboBox>
 
@@ -23,19 +23,20 @@ FilterActionMissingTransportDialog::FilterActionMissingTransportDialog(const QSt
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select Transport"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QLabel *label = new QLabel(this);
+    auto label = new QLabel(this);
     label->setObjectName(QStringLiteral("label"));
-    label->setText(i18n("Filter transport is missing. "
-                        "Please select a transport to use with filter \"%1\"",
-                        filtername));
+    label->setText(
+        i18n("Filter transport is missing. "
+             "Please select a transport to use with filter \"%1\"",
+             filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
     mComboBoxTransport = new MailTransport::TransportComboBox(this);
     mComboBoxTransport->setObjectName(QStringLiteral("comboboxtransport"));
     mainLayout->addWidget(mComboBoxTransport);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
