@@ -84,10 +84,10 @@ FilterAction::ReturnCode FilterActionDecrypt::process(ItemContext &context, bool
 
 QWidget *FilterActionDecrypt::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *l = new QVBoxLayout(w);
+    auto w = new QWidget(parent);
+    auto l = new QVBoxLayout(w);
 
-    QLabel *lbl = new QLabel(w);
+    auto lbl = new QLabel(w);
 
     QPalette palette = lbl->palette();
     palette.setColor(lbl->foregroundRole(), KColorScheme(QPalette::Normal).foreground(KColorScheme::NegativeText).color());
@@ -95,8 +95,9 @@ QWidget *FilterActionDecrypt::createParamWidget(QWidget *parent) const
     lbl->setWordWrap(true);
 
     lbl->setText(i18n("<b>Warning:</b> Decrypted emails may be uploaded to a server!"));
-    lbl->setToolTip(i18n("<p>If the email folder that you are filtering into is connected to a remote "
-                         "account (like an IMAP-Server) the decrypted content will go there.</p>"));
+    lbl->setToolTip(
+        i18n("<p>If the email folder that you are filtering into is connected to a remote "
+             "account (like an IMAP-Server) the decrypted content will go there.</p>"));
     l->addWidget(lbl);
 
     return w;
