@@ -84,7 +84,7 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
     for (QList<int>::ConstIterator it = argList.constBegin(); it != end; ++it) {
         // setup temp files with check for duplicate %n's
         if ((*it) != lastSeen) {
-            auto *tempFile = new QTemporaryFile();
+            auto tempFile = new QTemporaryFile();
             if (!tempFile->open()) {
                 delete tempFile;
                 qCDebug(MAILCOMMON_LOG) << "FilterActionWithCommand: Could not create temp file!";
@@ -129,7 +129,8 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
     return result;
 }
 
-namespace {
+namespace
+{
 /**
  * Substitutes placeholders in the command line with the
  * content of the corresponding header in the message.
@@ -139,8 +140,7 @@ void substituteMessageHeaders(const KMime::Message::Ptr &aMsg, QString &result)
 {
     // Replace the %{foo} with the content of the foo header field.
     // If the header doesn't exist, remove the placeholder.
-    const QRegularExpression header_rx(QStringLiteral("%\\{([a-z0-9-]+)\\}"),
-                                       QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression header_rx(QStringLiteral("%\\{([a-z0-9-]+)\\}"), QRegularExpression::CaseInsensitiveOption);
     int offset = 0;
     QRegularExpressionMatch rmatch;
     while (result.indexOf(header_rx, offset, &rmatch) != -1) {
@@ -178,7 +178,7 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &co
 
     // KProcess doesn't support a QProcess::launch() equivalent, so
     // we must use a temp file :-(
-    auto *inFile = new QTemporaryFile;
+    auto inFile = new QTemporaryFile;
     if (!inFile->open()) {
         delete inFile;
         return ErrorButGoOn;
@@ -253,7 +253,7 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &co
             }
             if (uid != newUid) {
                 aMsg->setFrozen(false);
-                auto *header = new KMime::Headers::Generic("X-UID");
+                auto header = new KMime::Headers::Generic("X-UID");
                 header->fromUnicodeString(uid, "utf-8");
                 aMsg->setHeader(header);
                 aMsg->assemble();
