@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -20,9 +20,6 @@ private Q_SLOTS:
     void testImportAndFilters();
     void testImportOrFilters();
     void testImportTypeFilters();
-
-private:
-    void initialize();
 };
 
 #endif // FILTERIMPORTTHUNDERBIRDTEST_H
