@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -12,7 +12,7 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-    MailCommon::MDNAdviceDialog *w = new MailCommon::MDNAdviceDialog(QStringLiteral("test mnda"), true);
+    auto w = new MailCommon::MDNAdviceDialog(QStringLiteral("test mnda"), true);
     MessageComposer::MDNAdvice rc = MessageComposer::MDNIgnore;
     if (w->exec()) {
         rc = w->result();
