@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,22 +14,23 @@
 
 #include <KLocalizedString>
 #include <KSharedConfig>
-namespace {
-static const char myConfigGroupName[] = "SnippetCustomFileAttachmentNameDialog";
+namespace
+{
+static const char mySnippetCustomFileAttachmentNameDialogGroupName[] = "SnippetCustomFileAttachmentNameDialog";
 }
 using namespace MailCommon;
 SnippetCustomFileAttachmentNameDialog::SnippetCustomFileAttachmentNameDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Customize File Name Attachment"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
 
     mCustomWidget = new SnippetCustomFileAttachmentNameWidget(this);
     mCustomWidget->setObjectName(QStringLiteral("mCustomWidget"));
     mainLayout->addWidget(mCustomWidget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("button"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -49,7 +50,7 @@ SnippetCustomFileAttachmentNameDialog::~SnippetCustomFileAttachmentNameDialog()
 
 void SnippetCustomFileAttachmentNameDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openConfig(), mySnippetCustomFileAttachmentNameDialogGroupName);
 
     const QSize size = group.readEntry("Size", QSize(500, 150));
     if (size.isValid()) {
@@ -59,7 +60,7 @@ void SnippetCustomFileAttachmentNameDialog::readConfig()
 
 void SnippetCustomFileAttachmentNameDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openConfig(), mySnippetCustomFileAttachmentNameDialogGroupName);
     group.writeEntry("Size", size());
 }
 
