@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,11 +10,13 @@
 
 #include <QWidget>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class ComposerLineEdit;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 class RedirectWidget : public QWidget
 {
     Q_OBJECT
